OTRSTicketCreateResponse = {
    "TicketID": "1",
    "TicketNumber": "2018081300000001",
    "ArticleID": "11",
}

OTRSTicketGetResponse = {
    "TicketID": "2",
    "TicketNumber": "2018081300000002",
    "StateID": "2",
    "State": "closed successful",
    "StateType": "closed",
    "TypeID": "4",
    "Type": "Petici\xf3n",
    "ServiceID": "70",
    "Service": "Banda Ancha::ADSL::Provisi\xf3 ADSL",
    "QueueID": "21",
    "Queue": "Serveis de banda ampla::Provisi\xf3 ADSL::Realitzar comandes ADSL",
    "Title": "prova 106",
    "CustomerID": "example@mail.com",
    "PriorityID": "3",
    "Priority": "3 normal",
    "DynamicField": [
        {
            "Name": "ProcessManagementActivityID",
            "Value": "Activity-2add0d7a8235a9c91f8c594b199f6b89",
        },
        {
            "Name": "ProcessManagementProcessID",
            "Value": "Process-441820b536cb5b9899d12f729e6f5e97",
        },
        {"Name": "IDContracte", "Value": "1022"},
        {"Name": "nomSoci", "Value": "Pere"},
        {"Name": "cognom1", "Value": "Pablo"},
        {"Name": "NIFNIESoci", "Value": "123456789"},
        {"Name": "correuElectronic", "Value": "pere.pablo@email.coop"},  # Party
        {"Name": "NIFNIEtitular", "Value": "123456789"},
        {"Name": "dataIniciFacturacio", "Value": "2018-12-10 00:00:00"},
    ],
    "CustomerUserID": "example@mail.com",
}
